=======
Hacking
=======

Fork me at: https://github.com/icemac/icemac.addressbook

See `Source installation`_, too.

.. _`Source installation` : https://icemacaddressbook.readthedocs.io/en/latest/sourceinstallation.html
